Sma

Struct Sma 

pub struct Sma { /* private fields */ }
Simple Moving Average indicator.

Computes the arithmetic mean of closing prices over the specified period.

Formula

SMA = (P1 + P2 + … + Pn) / n

where P is the closing price and n is the period.

Example

use quant_indicators::{Indicator, Sma};
use quant_primitives::Candle;
use chrono::Utc;
use rust_decimal_macros::dec;

let ts = Utc::now();
let candles: Vec<Candle> = (0..20).map(|i| {
    Candle::new(dec!(100), dec!(110), dec!(90), dec!(100) + rust_decimal::Decimal::from(i), dec!(1000), ts).unwrap()
}).collect();
let sma = Sma::new(20).unwrap();
let series = sma.compute(&candles).unwrap();

Implementations

Source

impl Sma

pub fn new(period: usize) -> Result<Self, IndicatorError>

Create a new SMA indicator with the specified period.

Errors

Returns InvalidParameter if period is 0.